#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json
from django import template
from bigbuild.models import Page
register = template.Library()


@register.filter
def jsonify(obj):
    """
    Returns an object in JSON format.
    """
    if isinstance(obj, Page):
        return json.dumps(obj.to_json())
    return json.dumps(obj)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from django.conf import settings
from bigbuild import get_base_url
from bigbuild import get_repo_branch


def bigbuild(request):
    """
    Adds env-related context variables to the context.
    """
    return {
        'BIGBUILD_BIGBAR': getattr(settings, 'BIGBUILD_BIGBAR', True),
        'BIGBUILD_GIT_BRANCH': get_repo_branch(),
        'BIGBUILD_BASE_URL': get_base_url()
    }



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from bigbuild.models import PageList
from django.core.management.base import BaseCommand
from django.core.serializers.python import Serializer


class BigBuildSerializer(Serializer):
    
    def get_dump_object(self, obj):
        data = OrderedDict([('model', force_text(obj._meta))])
        if not self.use_natural_primary_keys or not hasattr(obj, 'natural_key'):
            data["pk"] = force_text(obj._get_pk_val(), strings_only=True)
        data['fields'] = self._current
        return data


class Command(BaseCommand):
    help = 'Tests if page directories are valid'

    def handle(self, *args, **options):
        page_list = PageList()
        page = page_list[0]

        print page
